import pandas as pd

def load_municipios(path="populacao_estimada_completa_spline.csv"):
    df = pd.read_csv(path, sep=";")

    # garantir tipo correto
    df["cod_mun_ibge_6"] = df["cod_mun_ibge_6"].astype(str)

    # remover duplicados (um município aparece várias vezes por ano)
    df_unique = df[["cod_mun_ibge_6", "municipio"]].drop_duplicates()

    return df_unique
